@@ -7,9 +7,13 @@
 
 import tkinter
 
-from solentware_grid.gui.datarow import DataRow
-from solentware_grid.gui.datarow import GRID_COLUMNCONFIGURE, GRID_CONFIGURE
-from solentware_grid.gui.datarow import WIDGET_CONFIGURE, WIDGET, ROW
+from solentware_grid.gui.datarow import (
+    GRID_COLUMNCONFIGURE,
+    GRID_CONFIGURE,
+    WIDGET_CONFIGURE,
+    WIDGET,
+    ROW,
+    )
 
 from pgn_read.core.constants import (
     TAG_RESULT,
@@ -17,6 +21,7 @@ from pgn_read.core.constants import (
     IFG_TAG_VALUE,
     )
 
+from .datarow import DataRow
 from ..core.chessrecord import ChessDBrecordRepertoireTags
 from .repertoiredbedit import ChessDBeditRepertoire
 from .repertoiredbdelete import ChessDBdeleteRepertoire
